==> v1.0.8.tar.gz: thgtoa/donations.md <==
Donations to support this project are welcome (I'm definitely not a tech billionaire/millionaire and my budget is actually quite limited). 
Those donations are used to pay for Tor onion hosting (VPS), Mail hosting, and the Domain name (anonymousplanet.org). No profit is being made.
All donations and expenses are being logged here below for transparency.

<span style="color: red">***Current donation goals:***</span>

- Maintenance for current Tor Exit Nodes (4,50€/Month/Node, paid with XMR): 
	- Tor-Exit-01 node hosting (current expiration date is September 30, 2022).
	- Tor-Exit-02 node hosting (current expiration date is December 31, 2021). **Funding secured for extension.**
	- Tor-Exit-03 node hosting (current expiration date is August 31, 2022).
	- Tor-Exit-04 node hosting (current expiration date is September 30, 2022).
- Move VPS for the Tor .onion hosting (current expiration date is April 1st, 2022) to a cheaper hosting provider and extend for 2 more years.
- (Medium Priority) Set-up more Tor Exit nodes if funding allows it.
- (Low Priority) Set-up a Synapse Matrix Federated Server on a more powerful VPS (at least 2GB of RAM with enough storage to handle large rooms).
- Open to new suggestions for new possibilities if funding allows it (please use GitHub discussions for this).

**Donate anonymously using Monero (XMR):**

You can get Monero coins on any of those Exchanges: <https://www.getmonero.org/community/merchants/#exchanges> <sup>[[Archive.org]][4]</sup> (The well-known ones are a Binance, Bitfinex, Poloniex and Kraken).

Here is the address:

- ```4549BGJrEPBfpiPRL9CVGzGMgJnC1Dzf8EXLVfY8Ukrnj7LzkTV611dGf9tuQHiSQjbixsNWiffNiV5fPB3LkyF7UXi3vwQ```

![][1]

**Donate using Bitcoin (BTC):**

Here are the addresses:

- SegWit address: ```bc1qtall24j005qsd3dw8wahxhvged4vepn9fjp3my```
- Legacy address: ```17jYYV1x92fm9EVDbHuQjS5t9Qc44533Jw```

![][2]____________________![][3]

**Thank you for any contribution. All donations will be mentioned within this file.**
    
Donations log (UTC date/time):

- 2021-02-06 16:48:17: 0.1 XMR
- 2021-03-15 00:09: 1.24869 mBTC
- 2021-03-15 08:41: 0.07896 mBTC
- 2021-03-31 16:28: 1 XMR (Special thanks for this very generous donation)
- 2021-04-03 22:31: 0.5 XMR (Special thanks for this very generous donation)
- 2021-05-07 06:22: 0.010433355105 XMR
- 2021-06-16 03:05: 0.03 XMR
- 2021-06-27 18:39: 0.05 XMR
- 2021-07-12 07:24: 0.02 XMR
- 2021-07-16 14:31: 0.1 mBTC
- 2021-07-20 21:01: 0.058981 XMR
- 2021-07-24 15:16: 0.000000000001 XMR 
- 2021-07-25 02:37: 0.000000000001 XMR
- 2021-08-03 00:17: 0.04119191113 XMR
- 2021-08-07 15:05: 0.206328241262 XMR
- 2021-08-10 11:42: 0.21 mBTC
- 2021-08-13 00:25: 0.25 XMR
- 2021-08-14 04:58: 0.25588 mBTC
- 2021-08-30 17:32: 0.000000000001 XMR
- 2021-09-17 14:34: 0.018 XMR
- 2021-10-01 06:23: 0.000000002137 XMR
- 2021-10-02 19:16: 1 XMR (Special thanks for this very generous donation)

Total Monero donations received: **3.247861434515 XMR**
Total Bitcoin donations received: **1.89353 mBTC**

Spendings log (UTC date):

- 2021-03-12: 0.08181086 XMR (+fees) for domain anonymousplanet.org (1 year)
- 2021-03-16: 1.20179 mBTC (+fees) for domain anonymousplanet.org renewal (extension 3 years totalling 4 years)
- 2021-04-01: 0.8317 XMR (+fees) for basic VPS for Tor Mirror hosting
- 2021-04-05: 0.99367 mBTC (+fees +exchange from XMR to BTC) for Mail Hosting (1 year)
- 2021-04-13: 0.71895 mBTC (+fees +exchange from XMR to BTC) for Mail Hosting (extension to 2 years)
- 2021-04-25: 0.02892 mBTC (Wallet to Wallet transfer fee)
- 2021-07-13: 0.78463 mBTC (+fees +exchange from BTC to XMR) for consoliation
- 2021-07-13: 0.067261698061 XMR (+fees) for a Tor Exit Node (01) Hosting (3 months)
- 2021-07-15: 0.151959953047 XMR (+fees) for a Tor Exit Node (02) Hosting (6 months)
- 2021-08-16: 0.253331471239 XMR (+fees) for a Tor Exit Node (03) Hosting (12 months)
- 2021-08-18: AtomicSwap conversion from remaining mBTC (-0.56588) to XMR (+0.081904862179)
- 2021-08-19: 0.0644 XMR (+fees) for Mail Hosting extension
- 2021-09-18: 0.246971511836 XMR (+fees) for renewal 1 year of Tor Exit Node 01
- 2021-10-04: 0.26954 XMR (+fees) for securing the anonymousplanet.org domain name until 2029
- 2021-10-06: 0.236073464623 XMR (+fees) for a Tor Exit Node (04) Hosting (12 months)

Total Monero remaining: **0.591326393010 XMR**
Total Bitcoin remaining: **0 mBTC**

[1]: media/monero.jpg
[2]: media/bitcoin-segwit.jpg
[3]: media/bitcoin-legacy.jpg
[4]: https://web.archive.org/web/https://www.getmonero.org/community/merchants/#exchanges

==> v1.1.1.tar.gz: thgtoa/donations.md <==
Donations to support this project are welcome as the funding of this project is limited. 
Those donations are used to pay for Tor onion hosting (VPS), mail hosting, domain name registration, and to maintain/run Tor exit nodes. **No profit is ever being made**.
All donations and spendings are being logged here below for transparency.

<span style="color: red">***Current donation goals:***</span>

- Maintenance for the Tor Exit Nodes, see them here: <https://metrics.torproject.org/rs.html#search/family:970814F267BF3DE9DFF2A0F8D4019F80C68AEE26>
- Move the Tor .onion hosting on a different cheaper VPS by April 1st, 2022, and extend hosting for 2 more years.
- Set-up more Tor Exit nodes if funding allows it.
- Open to new suggestions for new possibilities if funding allows it.

**Donate anonymously using Monero (XMR):**

Here is the address:

- ```4549BGJrEPBfpiPRL9CVGzGMgJnC1Dzf8EXLVfY8Ukrnj7LzkTV611dGf9tuQHiSQjbixsNWiffNiV5fPB3LkyF7UXi3vwQ```

![][1]

**Donate using Bitcoin (BTC):**

Here are the addresses:

- SegWit address: ```bc1qtall24j005qsd3dw8wahxhvged4vepn9fjp3my```
- Legacy address: ```17jYYV1x92fm9EVDbHuQjS5t9Qc44533Jw```

![][2]____________________![][3]

**Thank you for any contribution. All donations will be mentioned within this file.**
    
Donations log (UTC date/time):

- 2021-02-06 16:48:17: 0.1 XMR
- 2021-03-15 00:09: 1.24869 mBTC
- 2021-03-15 08:41: 0.07896 mBTC
- 2021-03-31 16:28: 1 XMR (Special thanks for this very generous donation)
- 2021-04-03 22:31: 0.5 XMR (Special thanks for this very generous donation)
- 2021-05-07 06:22: 0.010433355105 XMR
- 2021-06-16 03:05: 0.03 XMR
- 2021-06-27 18:39: 0.05 XMR
- 2021-07-12 07:24: 0.02 XMR
- 2021-07-16 14:31: 0.1 mBTC
- 2021-07-20 21:01: 0.058981 XMR
- 2021-07-24 15:16: 0.000000000001 XMR 
- 2021-07-25 02:37: 0.000000000001 XMR
- 2021-08-03 00:17: 0.04119191113 XMR
- 2021-08-07 15:05: 0.206328241262 XMR
- 2021-08-10 11:42: 0.21 mBTC
- 2021-08-13 00:25: 0.25 XMR
- 2021-08-14 04:58: 0.25588 mBTC
- 2021-08-30 17:32: 0.000000000001 XMR
- 2021-09-17 14:34: 0.018 XMR
- 2021-10-01 06:23: 0.000000002137 XMR
- 2021-10-02 19:16: 1 XMR (Special thanks for this very generous donation)
- 2021-10-17 15:40: 0.02 XMR
- 2021-10-18 16:06: 0.1958 XMR

Total Monero donations received: **3.463661434515 XMR**
Total Bitcoin donations received: **1.89353 mBTC**

Spendings log (UTC date):

- 2021-03-12: 0.08181086 XMR (+fees) for domain anonymousplanet.org (1 year)
- 2021-03-16: 1.20179 mBTC (+fees) for domain anonymousplanet.org renewal (extension 3 years totalling 4 years)
- 2021-04-01: 0.8317 XMR (+fees) for basic VPS for Tor Mirror hosting
- 2021-04-05: 0.99367 mBTC (+fees +exchange from XMR to BTC) for Mail Hosting (1 year)
- 2021-04-13: 0.71895 mBTC (+fees +exchange from XMR to BTC) for Mail Hosting (extension to 2 years)
- 2021-04-25: 0.02892 mBTC (Wallet to Wallet transfer fee)
- 2021-07-13: 0.78463 mBTC (+fees +exchange from BTC to XMR) for consoliation
- 2021-07-13: 0.067261698061 XMR (+fees) for a Tor Exit Node (01) Hosting (3 months)
- 2021-07-15: 0.151959953047 XMR (+fees) for a Tor Exit Node (02) Hosting (6 months)
- 2021-08-16: 0.253331471239 XMR (+fees) for a Tor Exit Node (03) Hosting (12 months)
- 2021-08-18: AtomicSwap conversion from remaining mBTC (-0.56588) to XMR (+0.081904862179)
- 2021-08-19: 0.0644 XMR (+fees) for Mail Hosting extension
- 2021-09-18: 0.246971511836 XMR (+fees) for renewal 1 year of Tor Exit Node 01
- 2021-10-04: 0.26954 XMR (+fees) for securing the anonymousplanet.org domain name until 2029
- 2021-10-06: 0.236073464623 XMR (+fees) for a Tor Exit Node (04) Hosting (12 months)
- 2021-10-18: 0.01952 XMR (+fees) for testing a new VPS hosting provider (Privex.io) for one month
- 2021-10-30: 0.240787814495 XMR (+fees) for a Synapse Hosting VPS (12 months) with bots to help grow the community. This is a test program that will be converted into a Tor Exit Node in case of failure

Total Monero remaining: **0.504345298515 XMR**
Total Bitcoin remaining: **0 mBTC**

[1]: media/monero.jpg
[2]: media/bitcoin-segwit.jpg
[3]: media/bitcoin-legacy.jpg
